<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE xsl:stylesheet [ 
<!ENTITY nbsp   "&#160;">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:output method="xml" version="1.0" encoding="iso-8859-1"
            doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN"
            doctype-system="http://www.w3.org/TR/2000/REC-xhtml1-20000126/DTD/xhtml1-strict.dtd"
            indent="yes"
            media-type="text/xml"/>


<xsl:param name="piclist" select="'piclist.xml'"/>
<xsl:param name="linklist" select="'linklist.xml'"/>

<!-- The following tags should appear in the output as tags -->
<xsl:template match="h1|h2|h3|h4|h5|h6|p" priority="-1">
  <xsl:element name="{name()}">
    <xsl:apply-templates/>
  </xsl:element>  
</xsl:template>


<!-- The following tags should not appear in the output but their content
     should be processed -->
<xsl:template match="body|keyword|controls-intro|basic|shortrefcopy" priority="-1">
  <xsl:apply-templates/>
</xsl:template>

<!-- The following tags should be deleted with their content -->
<xsl:template match="shortref" priority="-1">
</xsl:template>


<!-- All other tags should appear in the output AS BOLD TEXT so that it is 
     easy to spot tags for which no template has been specified -->
<xsl:template match="*" priority="-2">
  <b>&lt;<xsl:value-of select="name()"/>&gt;</b>
  <xsl:apply-templates/>
  <b>&lt;/<xsl:value-of select="name()"/>&gt;</b>
</xsl:template>


<!-- Handle tags starting with "anchor_" as anchors -->
<xsl:template match="*[starts-with(local-name(),'anchor_')]" priority="-1">
  <a name="{local-name()}" id="{local-name()}">
    <xsl:apply-templates/>
  </a>
</xsl:template>

<xsl:template match='/'>
  <xsl:element name="html" namespace="http://www.w3.org/1999/xhtml">
    <head>
      <title><xsl:value-of select="normalize-space(/manual/head/title)"/></title>
      <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1"/>
      <meta name="generator" content="brace2xml, XSLT"/>
      <meta name="description" content="{normalize-space(/manual/head/description)}"/>
      <xsl:variable name="keywords">
        <xsl:for-each select="//keyword">
          <xsl:variable name="keyword" select="normalize-space(.)"/>
          <xsl:if test="count(/descendant::keyword[normalize-space(.)=$keyword][1]|.)=1">   
            <xsl:value-of select="$keyword"/>
            <xsl:if test="position()!=last()">,</xsl:if>
          </xsl:if>
        </xsl:for-each>
      </xsl:variable>
      <meta name="keywords" content="{normalize-space($keywords)}"/>
      <meta name="robots" content="index, follow"/>
      
      <style type="text/css">
      <xsl:comment>
        h1, h2, h3, h4, h5, h6 {clear:both}
      </xsl:comment>
      </style>
    </head>
    
    <body>
      <xsl:apply-templates select="/manual/body"/> 
    </body>  
  </xsl:element>
</xsl:template>



<xsl:template match="image-row">
  <table border="0">
    <tr align="center">
      <xsl:for-each select="image">
        <td>
          <xsl:call-template name="plain-image"/>
        </td>
        <td>&nbsp;&nbsp;&nbsp;</td>
      </xsl:for-each>
    </tr>
    <!-- some empty space to prevent xsltproc from putting everything into
           one line -->
    <xsl:text>
      
    </xsl:text>
    <tr align="center">
      <xsl:for-each select="image">
        <td>
          <i><xsl:value-of select="string(caption)"/></i>
        </td>
        <td>&nbsp;&nbsp;&nbsp;</td>
      </xsl:for-each>
    </tr>
  </table>
</xsl:template>



<xsl:template match="image[caption]" priority="1">
   <table border="0">
     <tr align="center">
       <td>
         <xsl:call-template name="plain-image"/>
       </td>
     </tr>
     <tr align="center">
       <td>
         <i><xsl:value-of select="string(caption)"/></i>
       </td>  
     </tr>
   </table>  
</xsl:template>



<xsl:template name="plain-image" match="image">
  <xsl:variable name="imgdsc" select="document($piclist)/images/image[normalize-space(@id)=normalize-space(current()/text())]"/>    
  <xsl:variable name="url" select="string($imgdsc/@src)"/>
  <xsl:variable name="alt" select="string($imgdsc/@alt)"/>
  <xsl:variable name="title" select="string($imgdsc/@title)"/>
  <xsl:variable name="width" select="string($imgdsc/@width)"/>
  <xsl:variable name="height" select="string($imgdsc/@height)"/>
  
  <xsl:choose>
    <xsl:when test="float"> 
      <img src="{$url}" alt="{$alt}" title="{$title}" 
           width="{$width}" height="{$height}" style="float:left; margin-right:2ex; margin-bottom:2ex;"/>
    </xsl:when>
    <xsl:otherwise>
      <img src="{$url}" alt="{$alt}" title="{$title}" 
           width="{$width}" height="{$height}"/>
    </xsl:otherwise>
  </xsl:choose>  
</xsl:template>







<xsl:template match="bullet-list">
  <ul type="circle">
    <xsl:apply-templates/>
  </ul>
</xsl:template>

<xsl:template match="bullet-list/item">
  <li>
    <xsl:apply-templates/>
  </li>
</xsl:template>



<xsl:template match="controls-list|menu-description">
  <xsl:param name="required-item-tag" select="''"/>
  <dl>
    <xsl:apply-templates>
      <xsl:with-param name="required-item-tag" select="$required-item-tag"/>
    </xsl:apply-templates>
  </dl>
</xsl:template>

<xsl:template match="controls-list/item|menu-description/item">
  <xsl:param name="required-item-tag" select="''"/>
  <xsl:if test="$required-item-tag='' or child::*[local-name()=$required-item-tag]">
    <xsl:for-each select="control|name">
      <dt>
        <strong><xsl:apply-templates/></strong>
      </dt>
    </xsl:for-each>  
    <dd>
      <xsl:apply-templates select="child::node()[not(self::control|self::name)]"/>
      <br/><br/>
    </dd>
  </xsl:if>  
</xsl:template>

<xsl:template match="fill-in-controls-intro">
  <xsl:apply-templates select="//controls-intro"/>
</xsl:template>

<xsl:template match="fill-in-basic-controls">
  <xsl:apply-templates select="//controls-list">
    <xsl:with-param name="required-item-tag" select="'basic'"/>
  </xsl:apply-templates>
</xsl:template>





<xsl:template match="term">
  <em><xsl:apply-templates/></em>
</xsl:template>






<xsl:template match="link">
  <xsl:variable name="id" select="normalize-space(concat(at,to))"/>
  <xsl:variable name="ref" select="string(document($linklist)/links/link[@id=$id]/@ref)"/>        
  
  <xsl:if test="$ref=''">
    <xsl:message terminate="yes">
      Cannot resolve link id '<xsl:value-of select="$id"/>' using linklist
      '<xsl:value-of select="$linklist"/>' !
    </xsl:message>
  </xsl:if>
  
  <xsl:variable name="anchor" select="string(document($linklist)/links/link[@id=$id]/@anchor)"/>    
  <xsl:variable name="fragment" select="$anchor"/>
  <xsl:if test="not(document($ref)/descendant::*[local-name()=$anchor])">
    <xsl:message terminate="yes">
      Anchor '<xsl:value-of select="$anchor"/>' not found in document 
      '<xsl:value-of select="$ref"/>' !
    </xsl:message>
  </xsl:if>
  
  <xsl:choose>
    <xsl:when test="generate-id(/)=generate-id(document($ref))">
      <xsl:call-template name="create-a-href">
        <xsl:with-param name="fragment" select="$fragment"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
        <xsl:choose>
            <!-- replace .xml with .html in actual link -->
            <xsl:when test="contains($ref,'.xml')">
                <xsl:call-template name="create-a-href">
                    <xsl:with-param name="fragment" select="$fragment"/>
                    <xsl:with-param name="ref" select="concat(substring-before($ref,'.xml'),'.html')"/>         
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="create-a-href">
                    <xsl:with-param name="fragment" select="$fragment"/>
                    <xsl:with-param name="ref" select="$ref"/>
                </xsl:call-template>
            </xsl:otherwise>  
        </xsl:choose>  
    </xsl:otherwise>
  </xsl:choose>  
</xsl:template>

<xsl:template name="create-a-href">
  <xsl:param name="ref" select="''"/>
  <xsl:param name="fragment" select="''"/>
  <a href="{$ref}#{$fragment}">
    <xsl:apply-templates select="child::node()[not(self::at|self::to)]"/>
  </a>
</xsl:template>


</xsl:stylesheet>


