/* Copyright (C) 2002 Matthias S. Benkmann <m.s.b@gmx.net>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2
of the License (ONLY THIS VERSION).

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package domino.logic;

import java.util.ConcurrentModificationException;

/**
* Iterates over a collection of <code>FormulaSyntaxNets</code>.
* An <code>FSNIterator</code> fails with a 
* {@link ConcurrentModificationException} if the underlying collection is
* modified. Note that this does not prevent all modifications anywhere in
* the <code>FormulaSyntaxNet</code>. Only modifications that add to or remove
* from the list of <code>FormulaSyntaxNet</code>s that the 
* <code>FSNIterator</code> iterates over will invalidate the iterator.
*/
public interface FSNIterator extends java.util.Iterator
{
  /** Returns true if the iteration has more elements. */
  public boolean hasNext();
  
  /** 
  * Returns the next element in the iteration.
  *
  * @return the next element in the iteration. 
  * @throws NoSuchElementException if the iteration has no more elements.
  * @see #nextFSN()
  */
  public Object next();
  
  /** 
  * Returns the next element in the iteration.
  * @return the next element in the iteration. 
  * @throws NoSuchElementException if the iteration has no more elements.
  * @see #next()
  */
  public FormulaSyntaxNet nextFSN();
  
  /**
  * <p>If the node returned by the most recent call to
  * {@link #next()} or {@link #nextFSN()} is a branch, this method returns
  * true if it has to be 
  * processed now in a preorder iteration. If the node returned is a leaf,
  * this method always returns true.</p>
  * <p>If {@link #next()} or {@link #nextFSN()} was not called prior to
  * calling this method, its return value is unspecified.</p>
  */
  public boolean preorder();
  
  /**
  * <p>If the node returned by the most recent call to
  * {@link #next()} or {@link #nextFSN()} is a branch, this method returns
  * true if it has to be 
  * processed now in a postorder iteration. If the node returned is a leaf,
  * this method always returns true.</p>
  * <p>If {@link #next()} or {@link #nextFSN()} was not called prior to
  * calling this method, its return value is unspecified.</p>
  */
  public boolean postorder();
  
  /**
  * <p>If the node returned by the most recent call to
  * {@link #next()} or {@link #nextFSN()} is a branch, this method returns
  * true if it has to be 
  * processed now in an inorder iteration. If the node returned is a leaf,
  * this method always returns true.</p>
  * <p>If {@link #next()} or {@link #nextFSN()} was not called prior to
  * calling this method, its return value is unspecified.</p>
  */
  public boolean inorder();
};
