/* Copyright (C) 2002 Matthias S. Benkmann <m.s.b@gmx.net>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2
of the License (ONLY THIS VERSION).

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package domino.ui;

/**
* <p>The x,y,z coordinates of an {@link IsoBlock}.</p>
*/
public class IsoLocation
{
  /** x coordindate */
  public int x;
  /** y coordinate */
  public int y;
  /** z coordinate */
  public int z;
  
  /** 
  * <p>Returns <code>true</code> if <code>ob</code> is an <code>IsoLocation</code>
  * with the same coordinates.</p>
  */
  public boolean equals(Object ob) //TESTED
  {
    try{
      IsoLocation obi=(IsoLocation)ob;
      return (x==obi.x) && (y==obi.y) && (z==obi.z);
    }
    catch(Exception X)
    {
      return false;
    }
  };
  
  /** 
  * <p>Returns a hash code for the object.</p> 
  */
  public int hashCode() //TESTED
  {
    //at least make sure the lower order bits are in different parts of the
    //returned hashcode to prevent generating the same hashcodes for coordinates
    //with low x,y,z values around 0,0,0
    int a=(x<<10)^(x>>>22);
    int b=(y<<20)^(y>>>12);
    return a^b^z;
  };
  
  /**
  * <p>Constructs an <code>IsoLocation</code> from the given coordinates.</p>
  */
  public IsoLocation(int X,int Y,int Z){x=X;y=Y;z=Z;}; //TESTED
  
  /**
  * <p>Creates a copy of <code>orig</code>.</p>
  */
  public IsoLocation(IsoLocation orig){x=orig.x;y=orig.y;z=orig.z;}; //TESTED
  
  /**
  * <p>Adds the x,y and z coordinates from <code>loc2</code> to the 
  * respective coordinates of <code>this</code>.</p>
  */
  public void add(IsoLocation loc2) //TESTED
  {
    x+=loc2.x;
    y+=loc2.y;
    z+=loc2.z;
  };

};

