/* Copyright (C) 2002 Matthias S. Benkmann <m.s.b@gmx.net>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; version 2
of the License (ONLY THIS VERSION).

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

package domino.ui;

/**
* <p>Used to fine-tune the position of an {@link IsoBlock}. The shift for x,y and
* z position is a floating point number between 0.0 (inclusive) and 1.0 (exclusive).
* An {@link IsoBlock} with a shift of (0,0,0) occupies only one {@link IsoLocation}.
* A block with a with a non-zero shift for all 3 coordinates occupies 8 
* {@link IsoLocation}s partially.</p>
*/
public class IsoShift
{
  /**
  * <p>Comparisons of <code>IsoShift</code> coordinates should consider differences 
  * less than this value to be 0.</p>
  */
  public final static double SHIFT_PRECISION=0.001;
  
  /** Shift in x direction. */
  public double x;
  /** Shift in y direction. */
  public double y;
  /** Shift in z direction. */
  public double z;

  /**
  * <p>Returns 0 if <code>abs(c1-c2)&lt;=SHIFT_PRECISION</code>, 
  * 1 if <code>c1-c2&gt;SHIFT_PRECISION</code>,
  * -1 if <code>c2-c1&gt;SHIFT_PRECISION</code>.
  * </p>
  */  
  public static int shiftCompare(double c1,double c2) //TESTED
  {
    c1-=c2;
    if (c1+SHIFT_PRECISION<0) return -1;
    if (c1-SHIFT_PRECISION>0) return +1;
    return 0;
  };
  
  /** Creates an <code>IsoShift</code> with the specified values.</p>*/
  public IsoShift(double X,double Y,double Z){x=X;y=Y;z=Z;}; //TESTED
  
  /** Creates a copy of <code>orig</code>.</p>*/
  public IsoShift(IsoShift orig){x=orig.x;y=orig.y;z=orig.z;};
  
  /** Creates an <code>IsoShift (0,0,0)</code>.</p>*/
  public IsoShift(){x=0;y=0;z=0;};
};


